package singletonexample;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;


/** Хронологический список, в котором хранится информация о всех действиях 
 * пользователя, которые он предпринимал
 */
public class HistoryList {
    // --------- Создаем единственный экземпляр класса и раздаем его --------
    private static HistoryList instance = new HistoryList() ;

    private HistoryList() { }

    public static HistoryList getInstance() {
        return instance;
    }


    // ----------- Список действий пользователя  ----------------------------
    private List history = Collections.synchronizedList( new ArrayList() );

    public void addCommand(String command) {
        history.add(command) ;
    }

    public String undoCommand() {
        return (String) history.remove(history.size() - 1) ;
    }

    @Override
    public String toString() {
        StringBuilder result = new StringBuilder() ;

        for(Object item : history) {
            result.append(" " ) ;
            result.append( item ) ;
            result.append("\n") ;
        }

        return result.toString() ;
    }
}
